<?php

namespace Fastrack\Property;

use PlatoCreative\Imgix\Imgix;
use SilverStripe\ORM\DataObject;
use SilverStripe\Security\Permission;
use SilverStripe\Security\PermissionProvider;
use SilverStripe\Security\Security;

/**
 * @property string Title
 * @property string Name
 * @property string Description
 */
class RoomType extends DataObject implements PermissionProvider
{
	private static $table_name = 'room_type';

	private static $db = [
		'Title' => 'Varchar(255)',
		'Name' => 'Varchar(255)',
		'Description' => 'Text'
	];

	private static $has_one = [
		'Icon' => Imgix::class,
	];

	private static $has_many = [
		'Rooms' => Room::class,
	];

	private static $translate = [
		'Title',
		'Name',
		'Description',
	];

	public function getCMSFields()
	{
		$fields = parent::getCMSFields();
		$fields->removeByName('Title');
		return $fields;
	}

	public function onBeforeWrite()
	{
		$this->Title = $this->Name;
		parent::onBeforeWrite();
	}

	public function providePermissions()
	{
		$permisions = [
			'MANAGE_ROOM_TYPES' => [
				'name' => 'Manage room types',
				'category' => 'Properties',
			],
		];
		$this->extend('updatePermisions', $permisions);
		return $permisions;
	}

	public function canView($member = null)
	{
		return Permission::check(['MANAGE_ROOM_TYPES']);
	}

	public function canEdit($member = null)
	{
		return Permission::check(['MANAGE_ROOM_TYPES']);
	}

	public function canDelete($member = null)
	{
		return Permission::check(['MANAGE_ROOM_TYPES']);
	}

	public function canCreate($member = null, $context = array())
	{
		return Permission::check(['MANAGE_ROOM_TYPES']);
	}



}
